@@ -1,21 +1,18 @@
-import json
-import os
-import re
-import semver
 import sys
 import tarfile
 import zipfile
 import urllib.request
+import io
 
 from invoke import task
 import semver
 import json
 import re
-import yaml
+
 from packaging import version
-from invoke.exceptions import ParseError
 from rdeploy.exceptions import ReleaseError
-from rdeploy.utils import get_settings, confirm, get_helm_bin
+
+from rdeploy.utils import get_settings, confirm, get_helm_bin, yaml_decode_data_fields, build_management_cmd
 
 # Cluster Activation:
 #####################
@@ -65,7 +62,7 @@ def set_cluster(ctx, config):
                             zone_or_region_param=zone_or_region_param),
                     echo=True)
 
-    
+
     else:
         if config_dict.get('cloud_zone'):
             zone_or_region_param = '--zone {}'.format(config_dict['cloud_zone'])
@@ -178,6 +175,17 @@ def upload_secrets(ctx, config, env_file):
                     env_file=env_file))
 
 
+@task(aliases=['decode-secret'])
+def decode_secret(ctx, config, secret):
+    """
+    Prints the decoded values of a kubernetes secret
+    """
+    set_context(ctx, config)
+    o = io.StringIO()
+    ctx.run('kubectl get secret {secret} -o yaml'.format(secret=secret),out_stream=o)
+    print(yaml_decode_data_fields(o.getvalue()))
+
+
 @task(aliases=['create-volume'])
 def create_volume(ctx, name,
                   zone='europe-west1-c',
@@ -371,8 +379,8 @@ def helm_setup(ctx, config):
         archive_tool = tarfile
     elif sys.platform == 'win32':
         os_string = 'windows-amd64'
-        archive_tool = zipfile   
-    
+        archive_tool = zipfile
+
     url = 'https://get.helm.sh/helm-v{version}-{os_string}.tar.gz'.format(version=helm_version,
                                                                           os_string=os_string)
     file_tmp = urllib.request.urlretrieve(url, filename=None)[0]
@@ -409,10 +417,8 @@ def shell(ctx, config):
     set_context(ctx, config)
     settings_dict = get_settings()
     config_dict = settings_dict['configs'][config]
-    ctx.run('kubectl exec -i -t {project_name}-management -- '
-            '/bin/sh -c "/bin/bash || /bin/sh"'
-            .format(project_name=config_dict['project_name']),
-            pty=True, warn=False, echo=True)
+    management_cmd = build_management_cmd(config_dict, "/bin/bash")
+    ctx.run(management_cmd, pty=True, warn=False, echo=True)
 
 
 @task
@@ -421,10 +427,8 @@ def manage(ctx, config, cmd):
     set_context(ctx, config)
     settings_dict = get_settings()
     config_dict = settings_dict['configs'][config]
-    ctx.run('kubectl exec -i -t {project_name}-management'
-            ' -- python  manage.py {cmd}'
-            .format(project_name=config_dict['project_name'], cmd=cmd),
-            pty=True, echo=True)
+    management_cmd = build_management_cmd(config_dict, f'python manage.py {cmd}')
+    ctx.run(management_cmd, pty=True, warn=False, echo=True)
 
 
 @task
@@ -492,7 +496,7 @@ def cloudbuild(ctx, config, tag):
                 ' --set TAG_NAME={tag_name}'
                 ' .'
                 .format(container_registry=provider_data['container_registry'],
-                        image_name=image_name, 
+                        image_name=image_name,
                         tag_name=tag), echo=True)
         else:
             log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
@@ -504,7 +508,7 @@ def cloudbuild(ctx, config, tag):
                 .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
                 echo=True)
 
-    
+
     else:
         log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
         project=config_dict['cloud_project'], image=image_name, tag_name=tag)
@@ -514,7 +518,7 @@ def cloudbuild(ctx, config, tag):
             ' --gcs-log-dir {log_dir}'
             .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
             echo=True)
-        
+
 
 @task(aliases=['cloudbuild-initial'])
 def cloudbuild_initial(ctx, config, tag):
@@ -536,7 +540,7 @@ def cloudbuild_initial(ctx, config, tag):
                 ' --set TAG_NAME={tag_name}'
                 ' .'
                 .format(container_registry=provider_data['container_registry'],
-                        image_name=image_name, 
+                        image_name=image_name,
                         tag_name=tag), echo=True)
         else:
             log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
@@ -547,7 +551,7 @@ def cloudbuild_initial(ctx, config, tag):
                     ' --gcs-log-dir {log_dir}'
                     .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
                     echo=True)
-    
+
     else:
         log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
         project=config_dict['cloud_project'], image=image_name, tag_name=tag)
@@ -557,8 +561,3 @@ def cloudbuild_initial(ctx, config, tag):
                 ' --gcs-log-dir {log_dir}'
                 .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
                 echo=True)
-
-
-
-
-
